==> theme-bootstrap-1.0.19.tgz: package/src/components/dropdown/dropdown-with-icon.jsx <==
import React, { Component } from 'react';
import PropTypes from 'prop-types';
import Label from 'reactstrap/lib/Label';
import { FormattedMessage } from 'react-intl';
import classNames from 'classnames';
import Dropdown from 'reactstrap/lib/Dropdown';
import DropdownMenu from 'reactstrap/lib/DropdownMenu';
import DropdownToggle from 'reactstrap/lib/DropdownToggle';
import DropdownItem from 'reactstrap/lib/DropdownItem';
import { IconArrowDown } from '../icons/icon-arrow-down/icon-arrow-down';
import './dropdown-with-icon.scss';

export class DropdownWithIcon extends Component {
  static propTypes = {
    data: PropTypes.arrayOf(PropTypes.string).isRequired,
    icon: PropTypes.node.isRequired,
    label: PropTypes.string,
    value: PropTypes.string,
    clickItem: PropTypes.func,
    className: PropTypes.string,
    disabled: PropTypes.bool,
  };

  static defaultProps = {
    value: '',
    clickItem: null,
    label: '',
    className: '',
    disabled: false,
  };

  state = {
    dropdownOpen: false,
  };

  toggleDropdown = () => {
    this.setState(previousState => ({
      dropdownOpen: !previousState.dropdownOpen,
    }));
  };

  render() {
    const { dropdownOpen } = this.state;
    const {
      data,
      label,
      className,
      icon,
      disabled,
    } = this.props;

    return (
      <Dropdown
        disabled={disabled}
        isOpen={dropdownOpen}
        toggle={this.toggleDropdown}
        className={classNames(className, 'd-flex dropdown-with-icon')}
      >
        <span className="icon-wrapper align-self-end">
          {icon}
        </span>
        <DropdownToggle nav disabled={disabled} className={classNames('p-0 w-100', { disabled })}>
          {label && <Label className="text-small text-gray-dark-hint"><FormattedMessage id={label} /></Label>}
          <div className="dropdown-field pb-0_5 d-flex justify-content-between">
            <div className="d-flex">
              <span className={classNames('h5', { 'text-gray-dark-secondary': disabled })}>{this.props.value}</span>
            </div>
            <IconArrowDown />
          </div>
        </DropdownToggle>
        <DropdownMenu left="true">
          {
            data.map(value => (
              <DropdownItem
                className="h5"
                key={value}
                value={value}
                onClick={this.props.clickItem}
              >
                {value}
              </DropdownItem>))
          }
        </DropdownMenu>
      </Dropdown>
    );
  }
}

==> theme-bootstrap-1.0.71.tgz: package/src/components/dropdown/dropdown-with-icon.jsx <==
import React, { Component } from 'react';
import PropTypes from 'prop-types';
import Label from 'reactstrap/lib/Label';
import { FormattedMessage } from 'react-intl';
import classNames from 'classnames';
import Dropdown from 'reactstrap/lib/Dropdown';
import DropdownMenu from 'reactstrap/lib/DropdownMenu';
import DropdownToggle from 'reactstrap/lib/DropdownToggle';
import DropdownItem from 'reactstrap/lib/DropdownItem';
import { IconArrowDown } from '../icons/icon-arrow-down/icon-arrow-down';
import './dropdown-with-icon.scss';

export class DropdownWithIcon extends Component {
  static propTypes = {
    data: PropTypes.arrayOf(PropTypes.string).isRequired,
    icon: PropTypes.node.isRequired,
    label: PropTypes.string,
    value: PropTypes.string,
    clickItem: PropTypes.func,
    className: PropTypes.string,
    disabled: PropTypes.bool,
  };

  static defaultProps = {
    value: '',
    clickItem: null,
    label: '',
    className: '',
    disabled: false,
  };

  state = {
    dropdownOpen: false,
  };

  toggleDropdown = () => {
    this.setState(previousState => ({
      dropdownOpen: !previousState.dropdownOpen,
    }));
  };

  render() {
    const { dropdownOpen } = this.state;
    const {
      data,
      label,
      className,
      icon,
      disabled,
    } = this.props;

    return (
      <Dropdown
        disabled={disabled}
        isOpen={dropdownOpen}
        toggle={this.toggleDropdown}
        className={classNames(className, 'd-flex dropdown-with-icon')}
      >
        <span className="icon-wrapper align-self-end">
          {icon}
        </span>
        <DropdownToggle nav disabled={disabled} className={classNames('p-0 w-100', { disabled })}>
          {label && <Label className="text-small text-gray-dark-hint"><FormattedMessage id={label} /></Label>}
          <div className="dropdown-field pb-0_5 d-flex justify-content-between align-items-center">
            <span className={classNames('h5', { 'text-gray-dark-secondary': disabled })}>{this.props.value}</span>
            <IconArrowDown />
          </div>
        </DropdownToggle>
        <DropdownMenu left="true">
          {
            data.map(value => (
              <DropdownItem
                className="h5"
                key={value}
                value={value}
                onClick={this.props.clickItem}
              >
                {value}
              </DropdownItem>))
          }
        </DropdownMenu>
      </Dropdown>
    );
  }
}
